Plan data structures
This module defines the core plan representation used throughout the SDK.
Structs
- Decision
Point - A decision point in the plan where Claude can make runtime decisions
- Plan
- A plan representing a sequence of steps to execute
- Plan
Step - A single step within a plan
- Retry
Policy - Retry policy for activities
Enums
- Activity
Spec - Specification for an activity to execute